Get Started Using Stravalib
============================

Installation
-------------

Stravalib is available on PyPI to be installed using easy_install or pip::

    $ pip install stravalib


.. toctree::
   :maxdepth: 2

   auth
   athletes
   activities
   overview
